@@ -1,12 +1,8 @@
+from django.conf import settings
 from django.db.models import ForeignKey
 from guardian.shortcuts import assign_perm, remove_perm
 from rest_framework.exceptions import ValidationError
 
-from django_utils.mock_request import MockRequest
-from global_requests import set_request, delete_request
-
-from django.conf import settings
-
 PUBLIC_VIEW_MODELS_LOWER = [model_name.lower() for model_name in getattr(settings, 'PUBLIC_VIEW_MODELS', [])]
 
 def get_model_name(obj_or_query):
